isInMultiWindowMode property
bool
get
isInMultiWindowMode
True when the window is known to be inside a multi-window mode.
Implementation
bool get isInMultiWindowMode;
True when the window is known to be inside a multi-window mode.
bool get isInMultiWindowMode;