publishContext static method
Publishes the window context used by facilitators and the full engine.
Implementation
static void publishContext(AppDimensContextLike context) =>
_contextSlot = context;
Publishes the window context used by facilitators and the full engine.
static void publishContext(AppDimensContextLike context) =>
_contextSlot = context;