AppDimensSnapshot class

Data carried by AppDimensProvider to descendants.

Constructors

AppDimensSnapshot({required DimenMetrics metrics, required AppDimensContext context, required UiModeType uiModeType})
const

Properties

context AppDimensContext
final
hashCode int
The hash code for this object.
no setteroverride
metrics DimenMetrics
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiModeType UiModeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override