AutoResizePercentBasis enum

Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens

Library: AppDimens

Resize subsystem — step tables and largest-fitting search (binary). Axis basis used by the percent-based resize helpers.

Inheritance
Available extensions

Values

height → const AutoResizePercentBasis
width → const AutoResizePercentBasis
minSide → const AutoResizePercentBasis

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AutoResizePercentBasis>
A constant List of the values in this enum, in order of their declaration.