CalcType enum
Calculation family encoded in a CacheKey.
Values
- auto → const CalcType
- diagonal → const CalcType
- fill → const CalcType
- fit → const CalcType
- fluid → const CalcType
- interpolated → const CalcType
- logarithmic → const CalcType
- percent → const CalcType
- perimeter → const CalcType
- power → const CalcType
- resize → const CalcType
- scaled → const CalcType
- unities → const CalcType
- aspectRatio → const CalcType
- density → const CalcType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited