fontScale property
double
get
fontScale
The configured font scale, normalized to a safe value.
Implementation
double get fontScale => _fontScaleRaw;
The configured font scale, normalized to a safe value.
double get fontScale => _fontScaleRaw;