isLandscape property
bool
get
isLandscape
True when the raw orientation code is landscape (2).
Implementation
bool get isLandscape =>
orientation == ScreenConfiguration.orientationLandscape;
True when the raw orientation code is landscape (2).
bool get isLandscape =>
orientation == ScreenConfiguration.orientationLandscape;