isPortrait property
bool
get
isPortrait
True when the raw orientation code is portrait (1).
Implementation
bool get isPortrait => orientation == ScreenConfiguration.orientationPortrait;
True when the raw orientation code is portrait (1).
bool get isPortrait => orientation == ScreenConfiguration.orientationPortrait;