DimenSsp class abstract final

EN: Static facade mirroring the Kotlin object DimenSsp.

PT: Fachada estática espelhando o object DimenSsp do Kotlin.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hsp(AppDimensContext context, num value, {bool fontScale = true}) double
ssp(AppDimensContext context, num value, {bool fontScale = true}) double
warmupCache(AppDimensContext context) → void
wsp(AppDimensContext context, num value, {bool fontScale = true}) double