DimensOrientation enum

Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens

Library: AppDimens

Device orientation codes shared by the configuration snapshot and builders.

Inheritance
Available extensions

Values

undefined → const DimensOrientation

EN Undefined / not resolved (matches Android ORIENTATION_UNDEFINED). PT Indefinida / não resolvida (equivale a ORIENTATION_UNDEFINED do Android).

portrait → const DimensOrientation

EN Portrait. PT Retrato.

landscape → const DimensOrientation

EN Landscape. PT Paisagem.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DimensOrientation>
A constant List of the values in this enum, in order of their declaration.