OrientationRequest enum

Builder-facing orientation request used by DimenScaled-style chains and facilitators (*Rotate).

Inheritance
Available extensions

Values

any → const OrientationRequest

EN Apply on both orientations (no orientation filter). PT Aplica nas duas orientações (sem filtro de orientação).

portrait → const OrientationRequest

EN Apply only in portrait. PT Aplica somente em retrato.

landscape → const OrientationRequest

EN Apply only in landscape. PT Aplica somente em paisagem.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OrientationRequest>
A constant List of the values in this enum, in order of their declaration.