ResizeBound class sealed

EN: Bound for a resize range: fixed dp, fixed sp, or a percent of an axis.

PT: Limite para um intervalo de redimensionamento: dp fixo, sp fixo ou um percentual de um eixo.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveToPx({required ScreenConfigurationLike configuration, required double density, required double fontScale}) double
Resolves this bound to physical pixels.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited