ResizePercent class

Percent-of-axis bound (value in 0…100).

Inheritance

Constructors

ResizePercent(double value, {DpQualifierLike axis = DpQualifierLike.smallWidth})
const

Properties

axis DpQualifierLike
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveToPx({required ScreenConfigurationLike configuration, required double density, required double fontScale}) double
Resolves this bound to physical pixels.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited