ScaledEntry class

One conditional branch inside a builder chain.

Constructors

ScaledEntry({UiModeType? uiModeType, DpQualifierEntry? dpQualifierEntry, OrientationRequest orientation = OrientationRequest.any, required double customValue, DpQualifier? finalQualifierResolver, required int priority, Inverter inverter = Inverter.standard, bool fontScale = true})
const

Properties

customValue double
final
dpQualifierEntry DpQualifierEntry?
final
finalQualifierResolver DpQualifier?
final
fontScale bool
final
hashCode int
The hash code for this object.
no setterinherited
inverter Inverter
final
orientation OrientationRequest
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiModeType UiModeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited