ScreenConfigurationLike class abstract interface

Screen-configuration subset needed by bounds (avoids widget imports).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenHeightDp double
no setter
screenWidthDp double
no setter
smallestWidthDp double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited