SnapshotCache class
Per-snapshot cache partition with bounded capacity.
Constructors
- SnapshotCache(DimenMetrics metrics)
Properties
-
entries
→ Map<
CacheKey, double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metrics → DimenMetrics
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
insert(
CacheKey key, double value) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited