StrategyChain class

EN: Generic conditional chain builder shared by the satellite strategies (DimenPercent.scaled(100)…, DimenPower.scaled(100)…). Same four-level priority model as DimenScaled; the winner value is scaled through the strategy formula.

PT: Construtor genérico de cadeias condicionais compartilhado pelas estratégias satélites (DimenPercent.scaled(100)…, …). Mesmo modelo de prioridades em quatro níveis de DimenScaled; o valor vencedor é escalado pela formula da estratégia.

Constructors

StrategyChain({required double base, List<ScaledEntry> entries = const [], bool ignoreMultiWindows = false, bool applyAspectRatio = false, double? customSensitivityK, required StrategyFormula formula, CalcType calcType = CalcType.auto})
const

Properties

applyAspectRatio bool
final
base double
final
calcType CalcType
final
customSensitivityK double?
final
entries List<ScaledEntry>
final
formula StrategyFormula
final
hashCode int
The hash code for this object.
no setterinherited
ignoreMultiWindows bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({DpQualifier qualifier = DpQualifier.smallWidth}) double
Resolves through the published scope (logical dp).
resolveFor(AppDimensContextLike scope, {DpQualifier qualifier = DpQualifier.smallWidth}) double
Resolves through an explicit scope (logical dp).
screen(UiModeType uiModeType, DpQualifier qualifierType, num qualifierValue, num customValue, {OrientationRequest orientation = OrientationRequest.any, DpQualifier? finalQualifierResolver, Inverter inverter = Inverter.standard}) StrategyChain
screenMode(UiModeType uiModeType, num customValue, {DpQualifier? finalQualifierResolver, OrientationRequest orientation = OrientationRequest.any, Inverter inverter = Inverter.standard}) StrategyChain
screenOrientation(OrientationRequest orientation, num customValue, {DpQualifier? finalQualifierResolver, Inverter inverter = Inverter.standard}) StrategyChain
screenQualifier(DpQualifier qualifierType, num qualifierValue, num customValue, {DpQualifier? finalQualifierResolver, OrientationRequest orientation = OrientationRequest.any, Inverter inverter = Inverter.standard}) StrategyChain
toString() String
A string representation of this object.
inherited
withAspectRatio({bool apply = true, double? sensitivityK}) StrategyChain
withIgnoreMultiWindows({bool ignore = true}) StrategyChain

Operators

operator ==(Object other) bool
The equality operator.
inherited