UnitType enum
Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens
Library: AppDimens
Physical / logical unit type used by the units module and radius helpers.
Values
- inch → const UnitType
-
EN International inch. PT Polegada internacional.
- cm → const UnitType
-
EN Centimeter. PT Centímetro.
- mm → const UnitType
-
EN Millimeter. PT Milímetro.
- sp → const UnitType
-
EN Scale-independent pixel (respects the system font scale). PT Pixel independente de escala (respeita a fonte do sistema).
- dp → const UnitType
-
EN Density-independent pixel. PT Pixel independente de densidade.
- px → const UnitType
-
EN Physical device pixel. PT Pixel físico do dispositivo.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited