CacheKey class
Immutable cache key (web-safe: no 64-bit bit packing, exact equality).
Constructors
Properties
- applyAspectRatio → bool
-
final
- baseValue → double
-
final
- calcType → CalcType
-
final
- customSensitivityK → double?
-
final
- hasCustomSensitivity → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- ignoreMultiWindows → bool
-
final
- inverter → Inverter
-
final
- isLandscape → bool
-
final
- qualifier → DpQualifier
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueType → ValueType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override