CacheStats class

Immutable cache statistics (mirrors KMP CacheStats).

Constructors

CacheStats({required int partitions, required int capacity, required int populated, required int hits, required int misses, required int evictions, required double hitRate})
const

Properties

capacity int
final
evictions int
final
hashCode int
The hash code for this object.
no setterinherited
hitRate double
final
hits int
final
misses int
final
partitions int
final
populated int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited