Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens
Library: AppDimens
Design reference constants shared across all strategy modules (no formulas).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- baseDiagonalDp → const double
- EN √(300² + 533²) — diagonal of the design baseline. PT √(300² + 533²) — diagonal da linha de base de design.
- baseHeightDp → const double
- EN Reference height of the design baseline. PT Altura de referência da linha de base de design.
- basePerimeterDp → const double
- EN 300 + 533 — perimeter of the design baseline. PT 300 + 533 — perímetro da linha de base de design.
- baseWidthDp → const double
- EN Reference smallest-width of the design baseline. PT Menor largura de referência da linha de base de design.
- invReferenceAspectRatio → const double
-
EN
1 / 1.78. PT1 / 1,78. - referenceAspectRatio → const double
- EN Reference aspect ratio (16:9 ≈ 1.78). PT Proporção de tela de referência (16:9 ≈ 1,78).