ScaledKernel class abstract final

EN: Shared fast-lane kernels — static, zero-allocation (one snapshot read

  • one multiply on the dominant paths).

PT: Kernels da faixa rápida — estáticos e sem alocação (uma leitura do snapshot + uma multiplicação nos caminhos dominantes).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

h(double base, bool mw) double
hAr(double base, bool mw) double
inverted(double base, Inverter inverter, {bool ar = false, bool mw = false}) double
sw(double base, bool mw) double
swAr(double base, bool mw) double
w(double base, bool mw) double
wAr(double base, bool mw) double