ScaledSp class
EN: Sp variant of DimenScaled — same priority model plus per-branch
fontScale control; started via 16.scaledSp.
PT: Variante sp de DimenScaled — mesmo modelo de prioridades com controle
de fontScale por ramo; iniciada via 16.scaledSp.
Constructors
Properties
- applyAspectRatio → bool
-
final
- base → double
-
final
- customSensitivityK → double?
-
final
-
entries
→ List<
ScaledEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreMultiWindows → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
AppDimensContext context, {DpQualifier qualifier = DpQualifier.smallWidth}) → double -
screen(
UiModeType uiModeType, DpQualifier qualifierType, num qualifierValue, num customValue, {OrientationRequest orientation = OrientationRequest.any, DpQualifier? finalQualifierResolver, Inverter inverter = Inverter.standard, bool fontScale = true}) → ScaledSp -
screenMode(
UiModeType uiModeType, num customValue, {DpQualifier? finalQualifierResolver, OrientationRequest orientation = OrientationRequest.any, Inverter inverter = Inverter.standard, bool fontScale = true}) → ScaledSp -
screenOrientation(
OrientationRequest orientation, num customValue, {DpQualifier? finalQualifierResolver, Inverter inverter = Inverter.standard, bool fontScale = true}) → ScaledSp -
screenQualifier(
DpQualifier qualifierType, num qualifierValue, num customValue, {DpQualifier? finalQualifierResolver, OrientationRequest orientation = OrientationRequest.any, Inverter inverter = Inverter.standard, bool fontScale = true}) → ScaledSp -
toString(
) → String -
A string representation of this object.
inherited
-
withAspectRatio(
{bool enable = true, double? sensitivityK}) → ScaledSp -
withIgnoreMultiWindows(
{bool ignore = true}) → ScaledSp
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited